==> huaweicloudsdkddm-3.0.52-py2.py3-none-any.whl: huaweicloudsdkddm/v1/model/node_list.py <==
# coding: utf-8

import re
import six





class NodeList:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'port': 'str',
        'status': 'str',
        'node_id': 'str',
        'ip': 'str'
    }

    attribute_map = {
        'port': 'port',
        'status': 'status',
        'node_id': 'node_id',
        'ip': 'ip'
    }

    def __init__(self, port=None, status=None, node_id=None, ip=None):
        """NodeList - a model defined in huaweicloud sdk"""
        
        

        self._port = None
        self._status = None
        self._node_id = None
        self._ip = None
        self.discriminator = None

        if port is not None:
            self.port = port
        if status is not None:
            self.status = status
        if node_id is not None:
            self.node_id = node_id
        if ip is not None:
            self.ip = ip

    @property
    def port(self):
        """Gets the port of this NodeList.

        端口。

        :return: The port of this NodeList.
        :rtype: str
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this NodeList.

        端口。

        :param port: The port of this NodeList.
        :type: str
        """
        self._port = port

    @property
    def status(self):
        """Gets the status of this NodeList.

        节点状态。

        :return: The status of this NodeList.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this NodeList.

        节点状态。

        :param status: The status of this NodeList.
        :type: str
        """
        self._status = status

    @property
    def node_id(self):
        """Gets the node_id of this NodeList.

        节点id。

        :return: The node_id of this NodeList.
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this NodeList.

        节点id。

        :param node_id: The node_id of this NodeList.
        :type: str
        """
        self._node_id = node_id

    @property
    def ip(self):
        """Gets the ip of this NodeList.

        ip

        :return: The ip of this NodeList.
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this NodeList.

        ip

        :param ip: The ip of this NodeList.
        :type: str
        """
        self._ip = ip

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NodeList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkddm-3.0.53-py2.py3-none-any.whl: huaweicloudsdkddm/v1/model/node_list.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class NodeList:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'port': 'str',
        'status': 'str',
        'node_id': 'str',
        'ip': 'str'
    }

    attribute_map = {
        'port': 'port',
        'status': 'status',
        'node_id': 'node_id',
        'ip': 'ip'
    }

    def __init__(self, port=None, status=None, node_id=None, ip=None):
        """NodeList - a model defined in huaweicloud sdk"""
        
        

        self._port = None
        self._status = None
        self._node_id = None
        self._ip = None
        self.discriminator = None

        if port is not None:
            self.port = port
        if status is not None:
            self.status = status
        if node_id is not None:
            self.node_id = node_id
        if ip is not None:
            self.ip = ip

    @property
    def port(self):
        """Gets the port of this NodeList.

        端口。

        :return: The port of this NodeList.
        :rtype: str
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this NodeList.

        端口。

        :param port: The port of this NodeList.
        :type: str
        """
        self._port = port

    @property
    def status(self):
        """Gets the status of this NodeList.

        节点状态。

        :return: The status of this NodeList.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this NodeList.

        节点状态。

        :param status: The status of this NodeList.
        :type: str
        """
        self._status = status

    @property
    def node_id(self):
        """Gets the node_id of this NodeList.

        节点id。

        :return: The node_id of this NodeList.
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this NodeList.

        节点id。

        :param node_id: The node_id of this NodeList.
        :type: str
        """
        self._node_id = node_id

    @property
    def ip(self):
        """Gets the ip of this NodeList.

        ip

        :return: The ip of this NodeList.
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this NodeList.

        ip

        :param ip: The ip of this NodeList.
        :type: str
        """
        self._ip = ip

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NodeList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
